<img src="https://cdn.worldvectorlogo.com/logos/speedtest.svg" height="120" style="float: right;margin: 0 0 5px 5px;" alt="sd">

# gui-speedtest-fastcom
Python GUI-tool to measure Internet speed with fast.com and speedtest.net. <br/>
Available functions: <br/>
 * Download speed from Speedtest.net
 * Upload speed from Speedtest.net
 * Ping from Speedtest.net
 * Download speed from fast.com

